package gov.usgs.earthquake.nshmp.netcdf.reader;

import static com.google.common.base.Preconditions.checkState;

import java.util.EnumMap;
import java.util.Map;

import gov.usgs.earthquake.nshmp.data.XySequence;
import gov.usgs.earthquake.nshmp.gmm.Imt;

@SuppressWarnings("serial")
public class StaticHazard extends EnumMap<Imt, XySequence> {

  public StaticHazard() {
    super(Imt.class);
  }

  private StaticHazard(EnumMap<Imt, XySequence> staticHazard) {
    super(Imt.class);
    putAll(staticHazard);
  }

  public Map<Imt, XySequence> staticHazard() {
    return Map.copyOf(this);
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    EnumMap<Imt, XySequence> staticHazard;

    private Builder() {
      staticHazard = new EnumMap<>(Imt.class);
    }

    public Builder put(Imt imt, XySequence xySequence) {
      staticHazard.put(imt, xySequence);
      return this;
    }

    public StaticHazard build() {
      checkState(!staticHazard.isEmpty(), "Must add hazards");
      return new StaticHazard(staticHazard);
    }
  }

}
